package reportinEngines;

import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.PrintWriter;
import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.util.ArrayList;

import dataModel.Dish;
import dataModel.Employee;
import dataModel.WeeklyStats;
/**
* <h1>ReportGeneratorForHTML</h1>
* Responsible for saving the restaurant statistics 
* in HTML format
*
* @version 1.0
* @since   2017-07-22
*/
public class ReportGeneratorForHTML implements IReportGenerator {

	/**
 	 * Creates and saves the data in HTML format
 	 * 
 	 */
	public void rasterToHTML(String fileName, String title, String[][] raster, int numRows, int numCols) {
		String header = new String("");
		header.concat("<!doctype html>");
		header.concat("\n");
		header.concat("<html>");
		header.concat("\n");
		header.concat("<head>");
		header.concat("\n");
		header.concat("<meta http-equiv=\"Content-Type\" content\"text/html; charset=windows-1253\">");
		header.concat("\n");
		header.concat(title);
		header.concat("\n");
		header.concat("</head>");
		header.concat("\n");
		header.concat("<body>");
		header.concat("\n");
		// Opening file to write, checking exception
		try {
			PrintWriter outputStream = new PrintWriter(new FileOutputStream(fileName)); // APPEND would be .... (new FileOutputStream(outputFileName, true));
			outputStream.println(header);

			outputStream.println("<table>");

			for(int i =0; i < numRows; i++){
				outputStream.println("<tr>");
				for(int j =0; j < numCols; j++){
					outputStream.print("<td>"+raster[i][j]+"</td>");
				}
				outputStream.println("\n</tr>");
			}
			outputStream.println("</table>");
			outputStream.println("</body>\n</html>");
			outputStream.close();
		} catch (FileNotFoundException e) {
			System.out.println("Problem opening files.");
			System.exit(0);
		}

	}// end visualize
	
	
	/**
 	 * Saves the statistics for the employees
 	 * 
 	 * @param personnel: list of employees
 	 */
	@Override
	public void reportOnEmps(ArrayList<Employee> personnel) {

		DecimalFormat df = new DecimalFormat("###.##");
		//df.setDecimalSeparatorAlwaysShown(true);
		DecimalFormatSymbols dfs=new DecimalFormatSymbols();			
		dfs.setDecimalSeparator('.');	//otherwise, the String.format conversion makes "," in GR environments; I want "." for decimals
		df.setDecimalFormatSymbols(dfs);		
	
		int numCols = 4;
		int numRows = WeeklyStats.getNumEmployees() + 1;
				
		String [][]raster = new String[numRows][numCols];
		raster[0][0] = "Name"; raster[0][1] = "Stars"; raster[0][2] = "#Orders"; raster[0][3] = "Salary";
		int i = 1;
		for(Employee e: personnel){
			raster[i][0] = e.getName(); 
			raster[i][1] = df.format(e.getEvaluation()); 
					//String.format( "%.2f",e.getEvaluation());
					//Double.toString(e.getEvaluation()); 
			raster[i][2] = Integer.toString(e.getNumberOfOrders()); 
			raster[i][3] = df.format(e.getSalary());  
					//Double.toString(e.getSalary());
			i++;			
		}
		rasterToHTML("./output/Emps.html", "Weekly Stats Emps", raster, numRows, numCols);
	}
	
	/**
 	 * Saves the statistics for the dishes
 	 * 
 	 * @param menu: list of dishes
 	 * 
 	 */
	@Override
	public void reportOnDishes(ArrayList<Dish> menu) {
		int numCols = 4;
		int numRows = WeeklyStats.getNumDishes() + 1;
		
		String [][]raster = new String[numRows][numCols];
		raster[0][0] = "Name"; raster[0][1] = "Gain"; raster[0][2] = "AvgTime"; raster[0][3] = "Stars";
		int i = 1;
		for(Dish d: menu){
			raster[i][0] = d.getDishName();
			raster[i][1] = Double.toString(d.getGain());
			raster[i][2] = Double.toString(d.getAvgTimeToMake());
			raster[i][3] = Double.toString(d.getEvaluation());
			i++;
		}
		rasterToHTML("./output/Dishes.html", "Weekly Stats Menu", raster, numRows, numCols);
	}

}
